Jupyter Client 5.1 — jupyter_client 5.1.0 documentation

# Jupyter Client 5.1

This package provides the Python API for starting, managing and communicating with Jupyter kernels.

Important

This document contains the authoritative description of the Jupyter messaging protocol. All developers are strongly encouraged to keep it updated as the implementation evolves, so that we have a single common reference for all protocol details.

User Documentation

- Messaging in Jupyter
  - Versioning
  - Introduction
  - General Message Format
  - Compatibility
  - The Wire Protocol
  - Python API
  - Messages on the shell (ROUTER/DEALER) channel
  - Messages on the IOPub (PUB/SUB) channel
  - Messages on the stdin (ROUTER/DEALER) channel
  - Heartbeat for kernels
  - Custom Messages
  - Notes

Developer documentation

- Making kernels for Jupyter
  - Connection files
  - Handling messages
  - Kernel specs
- Making simple Python wrapper kernels
  - Required steps
  - Example
  - Optional steps

API

- jupyter_client API
  - kernelspec - discovering kernels
  - manager - starting, stopping, signalling
  - client - communicating with kernels

Changes

- Changes in Jupyter Client
  - 5.1
  - 5.0
  - 4.4
  - 4.3
  - 4.2
  - 4.1
  - 4.0

# Indices and tables

- Index
- Module Index
- Search Page